==> jc-1.4.0.tar.gz: org/ietf/jgss/ChannelBinding.h <==
// public class org.ietf.jgss.ChannelBinding

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65d1d173dff3e647 org_ietf_jgss_ChannelBinding

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_ietf_jgss_ChannelBinding_H_
#define _JC_org_ietf_jgss_ChannelBinding_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_InetAddress$object;

// Typedefs
typedef struct _jc_org_ietf_jgss_ChannelBinding$sub_refs	_jc_org_ietf_jgss_ChannelBinding$sub_refs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs	_jc_org_ietf_jgss_ChannelBinding$sub_nonrefs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$refs	_jc_org_ietf_jgss_ChannelBinding$refs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$nonrefs	_jc_org_ietf_jgss_ChannelBinding$nonrefs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$object	_jc_org_ietf_jgss_ChannelBinding$object;

typedef const struct _jc_org_ietf_jgss_ChannelBinding$vmethods	_jc_org_ietf_jgss_ChannelBinding$vmethods;
typedef const struct _jc_org_ietf_jgss_ChannelBinding$vtable	_jc_org_ietf_jgss_ChannelBinding$vtable;
typedef const struct _jc_org_ietf_jgss_ChannelBinding$vtype	_jc_org_ietf_jgss_ChannelBinding$vtype;

// Constructors
extern void _jc_org_ietf_jgss_ChannelBinding$method$_init$3da913aa662d2c2e(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_net_InetAddress$object *, struct _jc_java_net_InetAddress$object *, struct _jc_byte_array *);
extern void _jc_org_ietf_jgss_ChannelBinding$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_byte_array *);

// Virtual methods
extern jboolean _jc_org_ietf_jgss_ChannelBinding$method$equals$8a15e0625571c581(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_net_InetAddress$object *_jc_org_ietf_jgss_ChannelBinding$method$getAcceptorAddress$6c9b5507f7be2fe4(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
extern _jc_byte_array *_jc_org_ietf_jgss_ChannelBinding$method$getApplicationData$ebbf5562fab225e4(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
extern struct _jc_java_net_InetAddress$object *_jc_org_ietf_jgss_ChannelBinding$method$getInitiatorAddress$c5b49f71ce0748e5(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
extern jint _jc_org_ietf_jgss_ChannelBinding$method$hashCode$53152098849316df(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);

// Virtual method descriptors
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getAcceptorAddress$6c9b5507f7be2fe4;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getApplicationData$ebbf5562fab225e4;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getInitiatorAddress$c5b49f71ce0748e5;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_org_ietf_jgss_ChannelBinding$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_net_InetAddress$object	*(*getAcceptorAddress$6c9b5507f7be2fe4)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
	_jc_byte_array	*(*getApplicationData$ebbf5562fab225e4)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
	struct _jc_java_net_InetAddress$object	*(*getInitiatorAddress$c5b49f71ce0748e5)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *);
};

// Vtable
struct _jc_org_ietf_jgss_ChannelBinding$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_ietf_jgss_ChannelBinding$vmethods	org_ietf_jgss_ChannelBinding;
};

// Vtype
struct _jc_org_ietf_jgss_ChannelBinding$vtype {
	_jc_type			type;
	_jc_org_ietf_jgss_ChannelBinding$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_ietf_jgss_ChannelBinding$sub_refs {
	_jc_byte_array	*appData;
	struct _jc_java_net_InetAddress$object	*initAddr;
	struct _jc_java_net_InetAddress$object	*acceptAddr;
};

// Reference instance fields (object)
struct _jc_org_ietf_jgss_ChannelBinding$refs {
    _jc_org_ietf_jgss_ChannelBinding$sub_refs	org_ietf_jgss_ChannelBinding;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_ietf_jgss_ChannelBinding$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs	org_ietf_jgss_ChannelBinding;
};

// Object instance structure
struct _jc_org_ietf_jgss_ChannelBinding$object {
	_jc_org_ietf_jgss_ChannelBinding$refs	refs[0];
	_jc_word		lockword;
	_jc_org_ietf_jgss_ChannelBinding$vtype	*vtype;
	_jc_org_ietf_jgss_ChannelBinding$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_ietf_jgss_ChannelBinding$vtype _jc_org_ietf_jgss_ChannelBinding$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_ChannelBinding, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_ChannelBinding$class_object;

#endif	/* _JC_org_ietf_jgss_ChannelBinding_H_ */

==> jc-1.4.6.tar.gz: org/ietf/jgss/ChannelBinding.h <==
// public class org.ietf.jgss.ChannelBinding

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65d1d173dff3e647 org_ietf_jgss_ChannelBinding

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_ietf_jgss_ChannelBinding_H_
#define _JC_org_ietf_jgss_ChannelBinding_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_InetAddress$object;

// Typedefs
typedef struct _jc_org_ietf_jgss_ChannelBinding$sub_refs	_jc_org_ietf_jgss_ChannelBinding$sub_refs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs	_jc_org_ietf_jgss_ChannelBinding$sub_nonrefs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$refs	_jc_org_ietf_jgss_ChannelBinding$refs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$nonrefs	_jc_org_ietf_jgss_ChannelBinding$nonrefs;
typedef struct _jc_org_ietf_jgss_ChannelBinding$object	_jc_org_ietf_jgss_ChannelBinding$object;

typedef const struct _jc_org_ietf_jgss_ChannelBinding$vmethods	_jc_org_ietf_jgss_ChannelBinding$vmethods;
typedef const struct _jc_org_ietf_jgss_ChannelBinding$vtable	_jc_org_ietf_jgss_ChannelBinding$vtable;
typedef const struct _jc_org_ietf_jgss_ChannelBinding$vtype	_jc_org_ietf_jgss_ChannelBinding$vtype;

// Constructors
extern void _jc_org_ietf_jgss_ChannelBinding$method$_init$3da913aa662d2c2e(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_net_InetAddress$object *, struct _jc_java_net_InetAddress$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_org_ietf_jgss_ChannelBinding$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_org_ietf_jgss_ChannelBinding$method$equals$8a15e0625571c581(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_InetAddress$object *_jc_org_ietf_jgss_ChannelBinding$method$getAcceptorAddress$6c9b5507f7be2fe4(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_org_ietf_jgss_ChannelBinding$method$getApplicationData$ebbf5562fab225e4(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_InetAddress$object *_jc_org_ietf_jgss_ChannelBinding$method$getInitiatorAddress$c5b49f71ce0748e5(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
extern jint _jc_org_ietf_jgss_ChannelBinding$method$hashCode$53152098849316df(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getAcceptorAddress$6c9b5507f7be2fe4;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getApplicationData$ebbf5562fab225e4;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$getInitiatorAddress$c5b49f71ce0748e5;
extern _jc_method _jc_org_ietf_jgss_ChannelBinding$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_org_ietf_jgss_ChannelBinding$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_InetAddress$object	*(*getAcceptorAddress$6c9b5507f7be2fe4)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getApplicationData$ebbf5562fab225e4)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_InetAddress$object	*(*getInitiatorAddress$c5b49f71ce0748e5)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_org_ietf_jgss_ChannelBinding$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_ietf_jgss_ChannelBinding$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_ietf_jgss_ChannelBinding$vmethods	org_ietf_jgss_ChannelBinding;
};

// Vtype
struct _jc_org_ietf_jgss_ChannelBinding$vtype {
	_jc_type			type;
	_jc_org_ietf_jgss_ChannelBinding$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_ietf_jgss_ChannelBinding$sub_refs {
	_jc_byte_array	*appData;
	struct _jc_java_net_InetAddress$object	*initAddr;
	struct _jc_java_net_InetAddress$object	*acceptAddr;
};

// Reference instance fields (object)
struct _jc_org_ietf_jgss_ChannelBinding$refs {
    _jc_org_ietf_jgss_ChannelBinding$sub_refs	org_ietf_jgss_ChannelBinding;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_ietf_jgss_ChannelBinding$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_ietf_jgss_ChannelBinding$sub_nonrefs	org_ietf_jgss_ChannelBinding;
};

// Object instance structure
struct _jc_org_ietf_jgss_ChannelBinding$object {
	_jc_org_ietf_jgss_ChannelBinding$refs	refs[0];
	_jc_word		lockword;
	_jc_org_ietf_jgss_ChannelBinding$vtype	*vtype;
	_jc_org_ietf_jgss_ChannelBinding$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_ietf_jgss_ChannelBinding$vtype _jc_org_ietf_jgss_ChannelBinding$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_ChannelBinding, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_ChannelBinding$class_object;

#endif	/* _JC_org_ietf_jgss_ChannelBinding_H_ */
